@@ -6,7 +6,7 @@ import pytest
 import itertools as it
 
 from pycvodes import (
-    integrate_adaptive, integrate_predefined, requires_jac, get_include, iterative_linsols
+    integrate_adaptive, integrate_predefined, requires_jac, get_include, iterative_linsols, sundials_version
 )
 
 
@@ -33,6 +33,12 @@ def high_precision(_test):
                               reason="test atol and/or rtol is too high for single precision")(_test)
 
 
+def double_precision(_test):
+    from .._config import env
+    return pytest.mark.skipif(env['SUNDIALS_PRECISION'] != "double",
+                              reason="test only verified for double precision")(_test)
+
+
 def test_get_include():
     assert get_include().endswith('include')
     assert 'cvodes_cxx.hpp' in os.listdir(get_include())
@@ -581,6 +587,33 @@ def test_dx0cb():
     assert xout[-1] == xend
 
 
+@pytest.mark.skipif(sundials_version < (3, 2, 0), reason="Sundials >=3.2.0 req. for constraints")
+@double_precision
+def test_constraints():
+    k = 1e23, 3.0, 4.0
+    y0 = [.7, .0, .0]
+    x0, xend = 0, 5
+    kwargs = dict(atol=1e-8, rtol=1e-8, method='bdf')
+    f, j = _get_f_j(k)
+    args = f, j, y0, x0, xend
+
+    def _check(xout, yout, info):
+        yref = decay_get_Cref(k, y0, xout)
+        assert np.allclose(yout, yref, atol=40*kwargs['atol'], rtol=40*kwargs['rtol'])
+        assert info['nfev'] > 0
+        assert info['njev'] > 0
+        assert info['success'] is True
+        assert xout[-1] == xend
+
+    xout1, yout1, info1 = integrate_adaptive(*args, **kwargs)
+    xout2, yout2, info2 = integrate_adaptive(*args, constraints=[1.0, 1.0, 1.0], **kwargs)
+
+    _check(xout1, yout1, info1)
+    _check(xout2, yout2, info2)
+
+    assert info2['n_steps'] < info1['n_steps'] - 2  # <-- thanks to constraints
+
+
 @high_precision
 def test_dx_max_cb():
     k = 1e23, 3.0, 4.0
